"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Union
from typing_extensions import TypeAliasType


EventMetadataOutputTypedDict = TypeAliasType(
    "EventMetadataOutputTypedDict", Union[str, int, float, bool]
)


EventMetadataOutput = TypeAliasType("EventMetadataOutput", Union[str, int, float, bool])



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class BenefitMeterCreditPropertiesTypedDict(TypedDict):
    r"""Properties for a benefit of type `meter_unit`."""

    units: int
    rollover: bool
    meter_id: str


class BenefitMeterCreditProperties(BaseModel):
    r"""Properties for a benefit of type `meter_unit`."""

    units: int

    rollover: bool

    meter_id: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class AggregationFunction(str, Enum):
    COUNT = "count"
    SUM = "sum"
    MAX = "max"
    MIN = "min"
    AVG = "avg"
    UNIQUE = "unique"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .alreadyactivesubscriptionerror import AlreadyActiveSubscriptionErrorData
from .notopencheckout import NotOpenCheckoutData
from .paymentnotready import PaymentNotReadyData
from dataclasses import dataclass, field
import httpx
from polar_sdk.models import PolarError
from typing import Optional, Union
from typing_extensions import TypeAliasType


CheckoutForbiddenErrorUnion = TypeAliasType(
    "CheckoutForbiddenErrorUnion",
    Union[AlreadyActiveSubscriptionErrorData, NotOpenCheckoutData, PaymentNotReadyData],
)


@dataclass(unsafe_hash=True)
class CheckoutForbiddenError(PolarError):
    data: CheckoutForbiddenErrorUnion = field(hash=False)

    def __init__(
        self,
        data: CheckoutForbiddenErrorUnion,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .customerpaymentmethod import CustomerPaymentMethod, CustomerPaymentMethodTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class CustomerPaymentMethodCreateSucceededResponseTypedDict(TypedDict):
    payment_method: CustomerPaymentMethodTypedDict
    status: Literal["succeeded"]


class CustomerPaymentMethodCreateSucceededResponse(BaseModel):
    payment_method: CustomerPaymentMethod

    STATUS: Annotated[
        Annotated[Literal["succeeded"], AfterValidator(validate_const("succeeded"))],
        pydantic.Field(alias="status"),
    ] = "succeeded"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class BenefitDiscordPropertiesTypedDict(TypedDict):
    r"""Properties for a benefit of type `discord`."""

    guild_id: str
    r"""The ID of the Discord server."""
    role_id: str
    r"""The ID of the Discord role to grant."""
    kick_member: bool
    r"""Whether to kick the member from the Discord server on revocation."""
    guild_token: str


class BenefitDiscordProperties(BaseModel):
    r"""Properties for a benefit of type `discord`."""

    guild_id: str
    r"""The ID of the Discord server."""

    role_id: str
    r"""The ID of the Discord role to grant."""

    kick_member: bool
    r"""Whether to kick the member from the Discord server on revocation."""

    guild_token: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productpricecustom import ProductPriceCustom, ProductPriceCustomTypedDict
from .productpricefixed import ProductPriceFixed, ProductPriceFixedTypedDict
from .productpricefree import ProductPriceFree, ProductPriceFreeTypedDict
from .productpricemeteredunit import (
    ProductPriceMeteredUnit,
    ProductPriceMeteredUnitTypedDict,
)
from .productpriceseatbased import ProductPriceSeatBased, ProductPriceSeatBasedTypedDict
from polar_sdk.utils import get_discriminator
from pydantic import Discriminator, Tag
from typing import Union
from typing_extensions import Annotated, TypeAliasType


ProductPriceTypedDict = TypeAliasType(
    "ProductPriceTypedDict",
    Union[
        ProductPriceFreeTypedDict,
        ProductPriceFixedTypedDict,
        ProductPriceSeatBasedTypedDict,
        ProductPriceCustomTypedDict,
        ProductPriceMeteredUnitTypedDict,
    ],
)


ProductPrice = Annotated[
    Union[
        Annotated[ProductPriceCustom, Tag("custom")],
        Annotated[ProductPriceFixed, Tag("fixed")],
        Annotated[ProductPriceFree, Tag("free")],
        Annotated[ProductPriceMeteredUnit, Tag("metered_unit")],
        Annotated[ProductPriceSeatBased, Tag("seat_based")],
    ],
    Discriminator(lambda m: get_discriminator(m, "amount_type", "amount_type")),
]
